%define _buildid .3

%global py26nvr python26-ecdsa-%{version}-%{release}
%global py26builddir %{_builddir}/%{py26nvr}
%global py26doc ../%{py26nvr}

%global py27nvr python27-ecdsa-%{version}-%{release}
%global py27builddir %{_builddir}/%{py27nvr}
%global py27doc ../%{py27nvr}

%bcond_without tests # with

%global upstream_name ecdsa

Name: python-ecdsa
Version: 0.11
Release: 3%{?_buildid}%{?dist}
Summary: ECDSA cryptographic signature library
Group: System Environment/Libraries
License: MIT
URL: https://pypi.python.org/pypi/ecdsa
# Remove the prime192v1 and secp224r1 curves for now
# https://bugzilla.redhat.com/show_bug.cgi?id=1067697
Source0: ecdsa-%{version}-clean.tar.gz
#Source0: https://pypi.python.org/packages/source/e/ecdsa/ecdsa-%{version}.tar.gz
BuildArch: noarch
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires: python26
BuildRequires: python27

%description
This is an easy-to-use implementation of ECDSA cryptography (Elliptic Curve
Digital Signature Algorithm), implemented purely in Python, released under
the MIT license. With this library, you can quickly create keypairs (signing
key and verifying key), sign messages, and verify the signatures. The keys
and signatures are very short, making them easy to handle and incorporate
into other protocols.

NOTE: The prime192v1 and secp224r1 curves are currently disabled.

%package -n python26-ecdsa
Summary: ECDSA cryptographic signature library
BuildRequires: python26-devel
BuildRequires: python26-setuptools
BuildRequires: python26-six
BuildRequires: openssl
Requires: python26-six
Provides: python-ecdsa = %{version}-%{release}

%description -n python26-ecdsa
This is an easy-to-use implementation of ECDSA cryptography (Elliptic Curve
Digital Signature Algorithm), implemented purely in Python, released under
the MIT license. With this library, you can quickly create keypairs (signing
key and verifying key), sign messages, and verify the signatures. The keys
and signatures are very short, making them easy to handle and incorporate
into other protocols.

NOTE: The prime192v1 and secp224r1 curves are currently disabled.

This package is meant to be used with Python 2.6.

%package -n python27-ecdsa
Summary: ECDSA cryptographic signature library
BuildRequires: python27-devel
BuildRequires: python27-setuptools
BuildRequires: python27-six
BuildRequires: openssl
Requires: python27-six

%description -n python27-ecdsa
This is an easy-to-use implementation of ECDSA cryptography (Elliptic Curve
Digital Signature Algorithm), implemented purely in Python, released under
the MIT license. With this library, you can quickly create keypairs (signing
key and verifying key), sign messages, and verify the signatures. The keys
and signatures are very short, making them easy to handle and incorporate
into other protocols.

NOTE: The prime192v1 and secp224r1 curves are currently disabled.

This package is meant to be used with Python 2.7.

%prep
%setup -q -n ecdsa-%{version}-clean

rm -rf ecdsa.egg-info
# Use system python-six
find -name \*.py | xargs sed -ie 's/from \(ecdsa\|\)\.six/from six/g'
rm ecdsa/six.py

%build
rm -rf %{py26builddir}
mkdir -p %{py26builddir}
cp -a * %{py26builddir}
pushd %{py26builddir}
CFLAGS="$RPM_OPT_FLAGS" %{__python26} setup.py build 
popd

rm -rf %{py27builddir}
mkdir -p %{py27builddir}
cp -a * %{py27builddir}
pushd %{py27builddir}
CFLAGS="$RPM_OPT_FLAGS" %{__python27} setup.py build 
popd
%__python26_shebang_path  %{py26builddir}
%__python27_shebang_path  %{py27builddir}

%install
rm -rf %{buildroot}

pushd %{py26builddir}
%{__python26} setup.py install -O1 --skip-build --root %{buildroot} --install-layout=amzn
popd

pushd %{py27builddir}
%{__python27} setup.py install -O1 --skip-build --root %{buildroot} --install-layout=amzn
popd

%check
%if %{with tests}
pushd %{py26builddir}
%{__python26} setup.py test
popd
pushd %{py27builddir}
%{__python27} setup.py test
popd
%endif

%clean
rm -rf %{buildroot}
rm -rf %{py26builddir}
rm -rf %{py27builddir}

%files -n python26-ecdsa
%doc LICENSE NEWS PKG-INFO README.md
%{python26_sitelib}/*

%files -n python27-ecdsa
%doc LICENSE NEWS PKG-INFO README.md
%{python27_sitelib}/*

%changelog
* Tue Mar 17 2015 Sean Kelly <seankell@amazon.com>
- Build for python 2.6 and 2.7

* Tue Aug 12 2014 Cristian Gafton <gafton@amazon.com>
- import source package EPEL7/python-ecdsa-0.11-3.el7
- setup complete for package python-ecdsa

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.11-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sat May 10 2014 Orion Poplawski <orion@cora.nwra.com> - 0.11-2
- Rebuild for Python 3.4

* Sat May 10 2014 Orion Poplawski <orion@cora.nwra.com> - 0.11-1
- Update to 0.11

* Mon Feb 24 2014 Orion Poplawski <orion@cora.nwra.com> - 0.10-3
- Add python3 package

* Mon Feb 24 2014 Orion Poplawski <orion@cora.nwra.com> - 0.10-2
- Use system python-six
- Remove extraneous #!s

* Fri Feb 21 2014 Orion Poplawski <orion@cora.nwra.com> - 0.10-1
- Initial package
